Learn R Programming

sleuth (version 0.28.0)

sleuth_results: Extract Wald test results from a sleuth object

Description

This function extracts Wald test results from a sleuth object.

Usage

sleuth_results(obj, test, test_type = "wt", which_model = "full",
  rename_cols = TRUE, show_all = TRUE)

Arguments

obj

a sleuth object

test

a character denoting the test to extract

which_model

a character string denoting the model. If extracting a wald test, use the model name. If extracting a likelihood ratio test, use 'lrt'.

rename_cols

if TRUE will rename some columns to be shorter and consistent with vignette

show_all

if TRUE will show all transcripts (not only the ones passing filters). The transcripts that do not pass filters will have NA values in most columns.

Value

a data.frame

See Also

sleuth_test to compute tests, models to view which models, tests to view which tests were performed (and can be extracted)