This function is a wrapper for fitting a measurement error model using
sleuth. It performs the technical variance estimation from the boostraps, biological
variance estimation, and shrinkage estimation.
sleuth_fit(obj, formula = NULL, fit_name = NULL, ...)a sleuth object
a formula specifying the design to fit OR a design matrix
the name to store the fit in the sleuth object
additional arguments passed to sliding_window_grouping and
shrink_df
a sleuth object with updated attributes
For most users, simply providing the sleuth object should be sufficient. By default, this behavior will fit the full model initially specified and store it in the sleuth object under 'full'.
To see which models have been fit, users will likely find the function
models helpful.
models for seeing which models have been fit,
sleuth_prep for creating a sleuth object,
sleuth_test to test whether a coefficient is zero