This function extracts Wald test results from a sleuth object.
sleuth_results(obj, test, test_type = "wt", which_model = "full",
rename_cols = TRUE, show_all = TRUE)a sleuth object
a character denoting the test to extract
a character string denoting the model. If extracting a wald test, use the model name. If extracting a likelihood ratio test, use 'lrt'.
if TRUE will rename some columns to be shorter and
consistent with vignette
if TRUE will show all transcripts (not only the ones
passing filters). The transcripts that do not pass filters will have
NA values in most columns.
a data.frame
sleuth_test to compute tests, models to
view which models, tests to view which tests were performed (and can be extracted)