Learn R Programming

sleuth (version 0.27.3)

sleuth_results: Extract Wald test results from a sleuth object

Description

This function extracts Wald test results from a sleuth object.

Usage

sleuth_results(obj, which_beta, which_model = "full", rename_cols = TRUE,
  show_all = TRUE)

Arguments

obj

a sleuth object

which_beta

a character string denoting which coefficient test to extract

which_model

a character string denoting which model to extract

rename_cols

if TRUE will rename some columns to be shorter and consistent with vignette

show_all

if TRUE will show all transcripts (not only the ones passing filters). The transcripts that do not pass filters will have NA values in most columns.

Value

a data.frame

See Also

wald_test to compute tests, models to view which models and betas have been tested