This function extracts Wald test results from a sleuth object.
sleuth_results(obj, which_beta, which_model = "full", rename_cols = TRUE,
show_all = TRUE)a sleuth object
a character string denoting which coefficient test to extract
a character string denoting which model to extract
if TRUE will rename some columns to be shorter and
consistent with vignette
if TRUE will show all transcripts (not only the ones
passing filters). The transcripts that do not pass filters will have
NA values in most columns.
a data.frame
wald_test to compute tests, models to
view which models and betas have been tested